@@ -9,7 +9,7 @@ use Carp qw(confess);
 
 # The following must be on the same line to ensure that $VERSION is read
 # correctly by PAUSE and installer tools. See docu of 'version'.
-use version 0.77; our $VERSION = version->declare("v2.2.1");
+use version 0.77; our $VERSION = version->declare("v2.2.2");
 
 
 sub new {
@@ -253,6 +253,10 @@ my $_parse_table = sub {
   for (++$index; $index < @$lines; ++$index) {
     (my $line = $lines->[$index]) =~ s/\s+$//;
     last if $line eq q{};
+    if ($pedantic) {
+      $line =~ /\S/;
+      $-[0] == $rule_pos->[0] or die("Wrong indentation at line " . ($index + 1));
+    }
     if ($line =~ /^\s*\|-/) {
       if ($pedantic) {
         $line eq $sep_line or die("Invalid row separator at line " . ($index + 1));
@@ -426,7 +430,7 @@ Text::Table::Read::RelationOn::Tiny - Read binary "relation on (over) a set" fro
 
 =head1 VERSION
 
-Version v2.2.1
+Version v2.2.2
 
 
 =head1 SYNOPSIS
@@ -869,6 +873,57 @@ B<Note>: Unlike C<matrix> the matrix returned by C<matrix_named> is not a data
 member and thus it is computed everytime you call this method.
 
 
+=head2 PITFALLS
+
+Basically, you do not need spaces around the C<|> separators. This table, for
+example, is perfectly fine:
+
+     |.|a|b|c|
+     |-+-+-+-|
+     |c| |X| |
+     |-+-+-+-|
+     |b| | | |
+     |-+-+-+-|
+     |a| | |X|
+
+However, if you have element names with a dash at the beginning, then you need
+a space at least after the first C<|> character. Example:
+
+=over
+
+=item B<WRONG>
+
+
+    | x\y   | this | that |-blah   |-    |
+    |-------+------+------+--------+-----|
+    | this  | X    |      | X      |  X  |
+    |-------+------+------+--------+-----|
+    | that  |      |      | X      |     |
+    |-------+------+------+--------+-----|
+    |-blah  |      | X    |        |     |
+    |-------+------+------+--------+-----|
+    |-      |      |      |        |     |
+    |-------+------+------+--------+-----|
+
+
+=item B<RIGHT>
+
+
+    | x\y   | this | that |-blah   |-    |
+    |-------+------+------+--------+-----|
+    | this  | X    |      | X      |  X  |
+    |-------+------+------+--------+-----|
+    | that  |      |      | X      |     |
+    |-------+------+------+--------+-----|
+    | -blah |      | X    |        |     |
+    |-------+------+------+--------+-----|
+    | -     |      |      |        |     |
+    |-------+------+------+--------+-----|
+
+=back
+
+
+
 =head1 AUTHOR
 
 Abdul al Hazred, C<< <451 at gmx.eu> >>
